@@ -6,7 +6,7 @@ from docutils.parsers.rst import Directive
 from sphinx import addnodes
 from sphinx.errors import SphinxError
 from sphinx.util.nodes import split_explicit_title, process_index_entry, set_role_source_info
-from htc_helpers import custom_ext_parser
+from htc_helpers import custom_ext_parser, make_headerlink_node
 
 def dump(obj):
     for attr in dir(obj):
@@ -26,8 +26,9 @@ def macro_def_role(name, rawtext, text, lineno, inliner, options={}, content=[])
     indexnode = addnodes.index()
     indexnode['entries'] = process_index_entry(f"pair: {knob}; {grouping}Configuration Options", targetid)
     set_role_source_info(inliner, lineno, indexnode)
+    headerlink_node = make_headerlink_node(knob, options)
 
-    return [indexnode, targetnode], []
+    return [indexnode, targetnode, headerlink_node], []
 
 def setup(app):
     app.add_role("macro-def", macro_def_role)
