@@ -584,9 +584,8 @@ CollectorDaemon::pending_query_entry_t *  CollectorDaemon::make_query_entry(
 	// followed by a char buffer for adtype name strings
 	cbq = pending_query_entry_t::size(num_adtypes);
 	cbt = target.size() + 1;
-	tagp = (char*) malloc(cbq+cbt);
-	query_entry = (pending_query_entry_t *) tagp;
-	tagp += cbq;
+	query_entry = (pending_query_entry_t *) malloc(cbq + cbt);
+	tagp = ((char *) query_entry) + cbq;
 
 	ASSERT(query_entry);
 	memset(query_entry, 0, cbq+cbt);
@@ -692,7 +691,7 @@ int CollectorDaemon::receive_query_cedar(int command,
 	bool is_locate;
 	bool negotiate_auth = false;
 	const unsigned int BIG_TABLE_MASK = (1<<GENERIC_AD) | (1<<ANY_AD) | (1<<MASTER_AD) | (1<<STARTDAEMON_AD)
-	                                  | (1<<STARTD_AD) | (1<<STARTD_PVT_AD) | (1<<SLOT_AD);
+	                                  | (1<<STARTD_AD) | (1<<STARTD_PVT_AD) | (1<<SLOT_AD) | (1<<BOGUS_AD);
 	KnownSubsystemId clientSubsys = SUBSYSTEM_ID_UNKNOWN;
 	AdTypes whichAds;
 	ClassAd *cad = new ClassAd();
@@ -2106,23 +2105,15 @@ void CollectorDaemon::Config()
 	// shared port without an assigned port number).
 	//
 
-	DCCollector * daemon = NULL;
-	collectorsToUpdate->rewind();
 	const char * myself = daemonCore->InfoCommandSinfulString();
 	if( myself == NULL ) {
 		EXCEPT( "Unable to determine my own address, aborting rather than hang.  You may need to make sure the shared port daemon is running first." );
 	}
 	Sinful mySinful( myself );
-	while( collectorsToUpdate->next( daemon ) ) {
-		const char * current = daemon->addr();
-		if( current == NULL ) { continue; }
-
-		Sinful currentSinful( current );
-		if( mySinful.addressPointsToMe( currentSinful ) ) {
-			collectorsToUpdate->deleteCurrent();
-			continue;
-		}
-	}
+	std::erase_if(collectorsToUpdate->getList(),
+			[&](DCCollector* curr) {
+				return curr->addr() && mySinful.addressPointsToMe(Sinful(curr->addr()));
+			} );
 
 	int i = param_integer("COLLECTOR_UPDATE_INTERVAL",900); // default 15 min
 	if( UpdateTimerId < 0 ) {
@@ -2471,7 +2462,7 @@ void CollectorDaemon::sendCollectorAd(int /* tid */)
 
 	// Send the ad
 	int num_updated = collectorsToUpdate->sendUpdates(UPDATE_COLLECTOR_AD, ad, NULL, false);
-	if ( num_updated != collectorsToUpdate->number() ) {
+	if ( num_updated != (int)collectorsToUpdate->getList().size() ) {
 		dprintf( D_ALWAYS, "Unable to send UPDATE_COLLECTOR_AD to all configured collectors\n");
 	}
 
