@@ -408,6 +408,8 @@ class FileTransfer final: public Service {
 
 	bool transferIsInProgress() const { return ActiveTransferTid != -1; }
 
+    const std::unordered_map< std::string, std::string > & GetProxyByMethodMap() { return proxy_by_method; }
+
   protected:
 
 	// Because FileTransferItem doesn't store the destination file name
@@ -504,7 +506,11 @@ class FileTransfer final: public Service {
 	bool PeerKnowsProtectedURLs{false};
 	bool TransferUserLog{false};
 	char* Iwd{nullptr};
-	StringList* ExceptionFiles{nullptr};
+#ifdef WIN32
+	std::vector<istring> ExceptionFiles;
+#else
+	std::vector<std::string> ExceptionFiles;
+#endif
 	StringList* OutputFiles{nullptr};
 	StringList* EncryptInputFiles{nullptr};
 	StringList* EncryptOutputFiles{nullptr};
@@ -726,6 +732,8 @@ class FileTransfer final: public Service {
     FileTransferList checkpointList;
 
     FileTransferList inputList;
+
+    std::unordered_map< std::string, std::string > proxy_by_method;
 };
 
 class UploadExitInfo {
